package com.goldenwater.slaj.ttsa.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.ttsa.domain.BisTtsaDesigndetail;

@Mapper
public interface BisTtsaDesigndetailMapper {
    BisTtsaDesigndetail selectBisTtsaDesigndetailByGuid(String guid);
    List<BisTtsaDesigndetail> selectBisTtsaDesigndetailList(BisTtsaDesigndetail bisTtsaDesigndetail);
    int insertBisTtsaDesigndetail(BisTtsaDesigndetail bisTtsaDesigndetail);
    int updateBisTtsaDesigndetail(BisTtsaDesigndetail bisTtsaDesigndetail);
    int deleteBisTtsaDesigndetailByGuid(String guid);
    int deleteBisTtsaDesigndetailByGuids(String[] guids);
}
